/* $Header: TestNTriple2NDMBatch.java 13-mar-2006.07:44:27 alwu Exp $ */

/* Copyright (c) 2005, 2006, Oracle. All rights reserved.  */

/*
   DESCRIPTION
    <short description of component this file declares/defines>

   PRIVATE CLASSES
    <list of private classes defined - with one-line descriptions>

   NOTES
    <other useful comments, qualifications, etc.>

   MODIFIED    (MM/DD/YY)
    alwu        03/13/06 - A bit clean up and merge description doc from MAIN
    nalexand    10/13/05 - nalexand_rdf_update_batching
    nalexand    10/12/05 - tablespace check 
    nalexand    10/10/05 - batchload testing 
    nalexand    10/09/05 - r2 patch testing 
    nalexand    10/06/05 - check value$cache 
    nalexand    09/27/05 - testing long_literals 
    nalexand    09/20/05 - testing batch loading 
    nalexand    09/19/05 - Creation
 */

/**
 *  @version $Header: TestNTriple2NDMBatch.java 13-mar-2006.07:44:27 alwu Exp $
 *  @author  nalexand
 *  @since   release specific (what release of product did this appear in)
 */

package oracle.spatial.rdf.client;
 
import java.io.FileNotFoundException;
import java.io.IOException;

import java.sql.DriverManager;
import java.sql.SQLException;

import oracle.jdbc.OracleConnection;
import oracle.jdbc.OracleDriver;

/**
 *  The TestNTriple2NDMBatch class provides an example of how to batch convert
 *  RDF data in N-Triple format to Oracle's RDF storage type, SDO_RDF_TRIPLE_S
 *  in Oracle10g R2 (10.2.0.2.0). This converter is recommended for
 *  batch-loading large datasets into an empty model in the Oracle RDF store.
 *
 * NOTES
 *  In order to use the TestNTriple2NDMBatch example and/or the 
 *   Java-based NTripleConverter the following requirements must be met:
 *
 *  1) Must have an Oracle10g R2 (10.2.0.2.0)+ database with Spatial installed
 *  2) Must have a user/password account for the database with DBA privileges
 *  3) Must have an RDF network created in the database
 *  4) Must have an RDF table with at least the columns 
 *     (id NUMBER, triple SDO_RDF_TRIPLE_S); and an RDF model 
 *     associated with the table.
 *  5) Must be using the following supplied Oracle10g R2 utilities 
 *     and JDBC libraries (JARs):
 *      ojdbc14.jar and sdordf.jar (10.2.0.2.0)
 *  6) Must have installed the Sun JDK version 1.4.2_04 or higher
 *  7) Must have an N-Triple file with no NULL fields. NULLs or 
 *     empty strings are NOT supported by Oracle's RDF data type.
 *
 * BATCH-LOADING INSTRUCTIONS
 *  1) DBA privileges are required by the user in order to batch-load 
 *  2) A tablespaceName parameter is required to use the bacth-loader; 
 *     use the tablespace on which the RDF network is installed 
 *     or other tablespace with enough room to store the data
 *  3) The model in which the data is to be batch-loaded, must be 
 *     empty; for loading into non-empty models, use the TestNTriple2NDM class
 *  4) Only one batch-loading session is allowed at a time, per database
 *  5) Inserts into the loading model from other sources while the 
 *     batch-loader is in use, will cause the batch-loading operation to 
 *     eventually fail
 *  6) Invalid N-Triple input will cause the batch-loader to fail; use 
 *     the TestNTriple2NDM class if your data has invalid triples
 *  7) IF the batch loading process fails for any reason, you must call 
 *     the SDO_RDF.CLEANUP_BATCH_LOAD() procedure, and address the 
 *     cause of failure before attempting to batch-load again.
 */
public class TestNTriple2NDMBatch 
{
  // Default constructor
  public TestNTriple2NDMBatch()
  {
  }

  protected static OracleConnection m_conn;

  // some default values 
  private static String ms_szUser = "scott";
  private static String ms_szPass = "tiger";
  private static String ms_szHost = "127.0.0.1";
  private static String ms_szSid  = "orcl";
  private static String ms_szPort = "1521";

  static
  { 
    // database connection for testing using scott/tiger
    OracleConnection conn = null;

    String szVal = null;
    if ((szVal = System.getProperty("db.user")) != null) {
      ms_szUser = szVal;
    }

    if ((szVal = System.getProperty("db.password")) != null) {
      ms_szPass = szVal;
    }

    if ((szVal = System.getProperty("db.host")) != null) {
      ms_szHost = szVal;
    }

    if ((szVal = System.getProperty("db.sid")) != null) {
      ms_szSid = szVal;
    }

    if ((szVal = System.getProperty("db.port")) != null) {
      ms_szPort = szVal;
    }
    
    try { 
      DriverManager.registerDriver(new OracleDriver()) ;
      
      String szJdbcConn = "jdbc:oracle:thin:@" + ms_szHost + ":" +
          ms_szPort + ":" + ms_szSid;

      System.out.println( "Note: You can use JVM properties -Ddb.user=<user> "
                        + "-Ddb.password=<password> "
                        + "-Ddb.host=<host> -Ddb.sid=<sid> -Ddb.port=<port> to "
                        + "configure database connection.");

      System.out.println("");

      System.out.println("Connecting to " + szJdbcConn + " as user " + 
          ms_szUser);
      System.out.flush();

      conn = (OracleConnection)DriverManager.getConnection(
          szJdbcConn, ms_szUser, ms_szPass); 
    } 
    catch(SQLException e) { 
      e.printStackTrace();
    }

    m_conn = conn;
  }


  /**
   * Entry point.
   * @param args
   */
  public static void main(String[] args)
    throws SQLException, FileNotFoundException, IOException
  {
    TestNTriple2NDMBatch testNTriple2NDMBatch = new TestNTriple2NDMBatch();

    try{

      NTripleConverter.setConnection(m_conn);

      if (args.length == 4) {
        System.out.println("Do not reuse blank nodes");
        String filename = args [0];
        String tableName = args [1];
        String tablespaceName = args [2];
        String modelName = args [3];
        NTripleConverter.nTriple2NDMBatch(filename,tableName,tablespaceName,modelName);
      }
      else if (args.length == 5) {
        System.out.println("Reuse blank nodes");
        String filename = args [0];
        String tableName = args [1];
        String tablespaceName = args [2];
        String modelName = args [3];
        int bnModelID = Integer.parseInt(args[4]); 

        NTripleConverter.nTriple2NDMBatch(filename,tableName,tablespaceName,
            modelName,bnModelID);
      } 
      else {
        System.err.println( "\nUsage " 
                          + "\n   java -Ddb.user=<user>  -Ddb.password=<password> "
                          + "-Ddb.host=<host> -Ddb.sid=<sid> -Ddb.port=<port>  "
                          + testNTriple2NDMBatch.getClass().getName() 
                          + " <NTripleFilename> <tablename> <tablespaceName> "
                          + " <modelName> [model_ID_forBlankNodeReuse] \n");
      }
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }
}
